@@ -218,6 +218,19 @@ bool QMarkdownTextEdit::eventFilter(QObject *obj, QEvent *event) {
         if ((keyEvent->key() == Qt::Key_Escape) && _searchWidget->isVisible()) {
             _searchWidget->deactivate();
             return true;
+        } else if (keyEvent->key() == Qt::Key_Insert &&
+                   keyEvent->modifiers().testFlag(Qt::NoModifier)) {
+            setOverwriteMode(!overwriteMode());
+
+            // This solves a UI glitch if the visual cursor was not properly
+            // updated when characters have different widths
+            QTextCursor cursor = this->textCursor();
+            cursor.movePosition(QTextCursor::Right);
+            setTextCursor(cursor);
+            cursor.movePosition(QTextCursor::Left);
+            setTextCursor(cursor);
+
+            return false;
         } else if ((keyEvent->key() == Qt::Key_Tab) ||
                    (keyEvent->key() == Qt::Key_Backtab)) {
             // handle entered tab and reverse tab keys
@@ -1687,6 +1700,14 @@ void QMarkdownTextEdit::updateLineNumberAreaWidth(int)
     if (newMargins != oldMargins) {
         setViewportMargins(newMargins);
     }
+
+    // Grow lineNumArea font-size with the font size of the editor
+    const int pointSize = this->font().pointSize();
+    if (pointSize > 0) {
+        QFont font = _lineNumArea->font();
+        font.setPointSize(pointSize);
+        _lineNumArea->setFont(font);
+    }
 }
 
 /**
