@@ -1,5 +1,6 @@
 #include <services/databaseservice.h>
 #include <services/metricsservice.h>
+#include <utils/cli.h>
 #include <utils/gui.h>
 #include <utils/misc.h>
 #include <utils/schema.h>
@@ -11,6 +12,7 @@
 #include <QStyleFactory>
 #include <QTranslator>
 #include <QtGui>
+#include <iostream>
 
 #include "dialogs/welcomedialog.h"
 #include "entities/notefolder.h"
@@ -89,8 +91,10 @@ inline void loadMacTranslations(QTranslator &translatorOSX, QTranslator &transla
  * Does the miscellaneous startup
  * If false is returned the app is supposed to quit
  */
-bool mainStartupMisc(const QStringList &arguments) {
+int mainStartupMisc(const QStringList &arguments) {
     QCommandLineParser parser;
+    QList<QCommandLineOption> allOptions;
+
     parser.setApplicationDescription("QOwnNotes " + QString(VERSION));
     const QCommandLineOption helpOption = parser.addHelpOption();
     const QCommandLineOption portableOption(
@@ -137,6 +141,17 @@ bool mainStartupMisc(const QStringList &arguments) {
         "name");
     parser.addOption(actionOption);
 
+    const QCommandLineOption completionOption(
+        QStringList() << "completion",
+        QCoreApplication::translate("main",
+                                    "Generate shell completion code. Supports `fish`, `bash`."),
+        "shell");
+    parser.addOption(completionOption);
+
+    allOptions << helpOption << portableOption << dumpSettingsOption << versionOption
+               << allowMultipleInstancesOption << clearSettingsOption << sessionOption
+               << actionOption << completionOption;
+
     // just parse the arguments, we want no error handling
     parser.parse(arguments);
 
@@ -145,6 +160,24 @@ bool mainStartupMisc(const QStringList &arguments) {
         parser.showHelp();
     }
 
+    // Check for completion option and generate script
+    if (parser.isSet(completionOption)) {
+        QString shell = parser.value(completionOption);
+        if (shell == "fish") {
+            Utils::Cli::generateFishCompletionScript(allOptions, QStringLiteral("QOwnNotes"));
+        } else if (shell == "bash") {
+            Utils::Cli::generateBashCompletionScript(allOptions, QStringLiteral("QOwnNotes"));
+            //        } else if (shell == "zsh") {
+            //            Utils::Cli::generateZshCompletionScript(allOptions,
+            //            QStringLiteral("QOwnNotes"));
+        } else {
+            std::cerr << "Unsupported shell type specified." << std::endl;
+            return 1;
+        }
+
+        return 0;    // Exit after generating the completion script
+    }
+
     QSettings settings;
     QString interfaceStyle = settings.value(QStringLiteral("interfaceStyle")).toString();
 
@@ -262,7 +295,7 @@ bool mainStartupMisc(const QStringList &arguments) {
                                   QObject::tr("Your note folder <b>%1</b> was not found any more! "
                                               "Do you want to select a new one?")
                                       .arg(notesPath)) != QMessageBox::Yes) {
-            return false;
+            return 1;
         }
 
         notesPath = QFileDialog::getExistingDirectory(
@@ -272,7 +305,7 @@ bool mainStartupMisc(const QStringList &arguments) {
         dir = QDir(notesPath);
 
         if (notesPath.isEmpty() || !dir.exists()) {
-            return false;
+            return 1;
         }
 
         settings.setValue(QStringLiteral("notesPath"), notesPath);
@@ -293,7 +326,7 @@ bool mainStartupMisc(const QStringList &arguments) {
             settings.clear();
             DatabaseService::removeDiskDatabase();
 
-            return false;
+            return 0;
         }
     }
 
@@ -311,10 +344,10 @@ bool mainStartupMisc(const QStringList &arguments) {
         // Print the dump to stdout and copy it to the clipboard
         fprintf(stdout, "%s\n", dump.toLocal8Bit().constData());
 
-        return false;
+        return 0;
     }
 
-    return true;
+    return -1;
 }
 
 /**
@@ -419,7 +452,7 @@ int main(int argc, char *argv[]) {
         } else if (arg == QStringLiteral("--clear-settings")) {
             clearSettings = true;
         } else if (arg == QStringLiteral("--help") || arg == QStringLiteral("--dump-settings") ||
-                   arg == QStringLiteral("-h") ||
+                   arg == QStringLiteral("--completion") || arg == QStringLiteral("-h") ||
                    arg == QStringLiteral("--allow-multiple-instances")) {
             allowOnlyOneAppInstance = false;
         } else if (arg == QStringLiteral("--after-update")) {
@@ -594,9 +627,9 @@ int main(int argc, char *argv[]) {
         loadMacTranslations(translatorOSX, translatorOSX2, translatorOSX3, translatorOSX4,
                             QCoreApplication::applicationDirPath(), locale);
 #endif
-        const bool result = mainStartupMisc(arguments);
-        if (!result) {
-            return 0;
+        const int result = mainStartupMisc(arguments);
+        if (result != -1) {
+            return result;
         }
 
         MainWindow w;
@@ -653,9 +686,9 @@ int main(int argc, char *argv[]) {
                             QCoreApplication::applicationDirPath(), locale);
 #endif
 
-        const bool result = mainStartupMisc(arguments);
-        if (!result) {
-            return 0;
+        const int result = mainStartupMisc(arguments);
+        if (result != -1) {
+            return result;
         }
 
         MainWindow w;
