@@ -447,6 +447,8 @@ class MainWindow : public QMainWindow {
 
     void onNavigationWidgetPositionClicked(int position);
 
+    void onBacklinkWidgetNoteClicked(int noteId);
+
     void startNavigationParser();
 
     void onNoteTextViewResize(QSize size, QSize oldSize);
@@ -713,6 +715,8 @@ class MainWindow : public QMainWindow {
 
     void on_actionEnable_AI_toggled(bool arg1);
 
+    void on_navigationTabWidget_currentChanged(int index);
+
    public:
     /** Settings access **/
     static bool isInDistractionFreeMode();
